---
title: Limiters
description: Hooks API reference
---

# Limiters

This module contains all the built-in limiter hooks contained in `arc`.

!!! note
    Any object that implements the [`LimiterProto`][arc.abc.limiter.LimiterProto] protocol is a valid limiter. If you are looking to create your custom ratelimiter implementation, you should start there.

::: arc.utils.hooks.limiters
